==> kdepim-4.14.7.tar.xz: kdepim-4.14.7/pimcommon/temporaryfile/attachmenttemporaryfilesdirs.h <==
/*
  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef ATTACHMENTTEMPORARYFILESDIRS_H
#define ATTACHMENTTEMPORARYFILESDIRS_H

#include <QObject>
#include <QStringList>
#include "pimcommon_export.h"

namespace PimCommon {

class PIMCOMMON_EXPORT AttachmentTemporaryFilesDirs : public QObject
{
    Q_OBJECT
public:
    explicit AttachmentTemporaryFilesDirs(QObject *parent = 0);
    ~AttachmentTemporaryFilesDirs();

    void addTempFile( const QString &file );
    void addTempDir( const QString &dir );
    QStringList temporaryFiles() const;
    void removeTempFiles();
    void forceCleanTempFiles();

    QStringList temporaryDirs() const;

    void setDelayRemoveAllInMs(int ms);

private Q_SLOTS:
    void slotRemoveTempFiles();

private:
    QStringList mTempFiles;
    QStringList mTempDirs;
    int mDelayRemoveAll;
};

}

#endif // ATTACHMENTTEMPORARYFILESDIRS_H

==> kdepim_15.08.2.orig.tar.xz: kdepim-15.08.2/pimcommon/temporaryfile/attachmenttemporaryfilesdirs.h <==
/*
  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef ATTACHMENTTEMPORARYFILESDIRS_H
#define ATTACHMENTTEMPORARYFILESDIRS_H

#include <QObject>
#include <QStringList>
#include "pimcommon_export.h"

namespace PimCommon
{

class PIMCOMMON_EXPORT AttachmentTemporaryFilesDirs : public QObject
{
    Q_OBJECT
public:
    explicit AttachmentTemporaryFilesDirs(QObject *parent = Q_NULLPTR);
    ~AttachmentTemporaryFilesDirs();

    void addTempFile(const QString &file);
    void addTempDir(const QString &dir);
    QStringList temporaryFiles() const;
    void removeTempFiles();
    void forceCleanTempFiles();

    QStringList temporaryDirs() const;

    void setDelayRemoveAllInMs(int ms);

private Q_SLOTS:
    void slotRemoveTempFiles();

private:
    QStringList mTempFiles;
    QStringList mTempDirs;
    int mDelayRemoveAll;
};

}

#endif // ATTACHMENTTEMPORARYFILESDIRS_H
